@@ -132,7 +132,7 @@ depthOf <- function(p,
   }
 
   # if there are non-NA results, return all of them
-  if (length(res) > 0 && any(!is.na(res))) {
+  if (length(res) > 0) {
     
     # backwards compatible: simplify=TRUE and SPC length is 1
     if (length(p) == 1 && simplify) {
@@ -188,12 +188,19 @@ depthOf <- function(p,
  
   if (inherits(res, 'data.frame')) {
   # otherwise, return the FUN value)) {
+    naldx <- logical(0)
+    if (all(is.na(res[[depthcol]]))) {
+      idx <- data.table::as.data.table(res)[, .I[1], by = id]$V1 
+    } else {
+      # handle warnings about e.g. no non-missing arguments to FUN
+      idx <- data.table::as.data.table(res)[, .I[.SD[[depthcol]] == suppressWarnings(FUN(.SD[[depthcol]], na.rm = na.rm))],
+                                            by = id, .SDcols = depthcol]$V1 
+      naldx <- is.na(idx)
+      idx <- idx[!naldx]
+    }
     
-    # handle warnings about e.g. no non-missing arguments to FUN
-    idx <- data.table::as.data.table(res)[, .I[.SD[[depthcol]] == suppressWarnings(FUN(.SD[[depthcol]], na.rm = na.rm))],
-                                          by = list(res[[id]]), .SDcols = depthcol]$V1
-    
-    res2 <- res[idx, c(idname(p), hzidname(p), depthcol, hzdesgn, "pattern")]
+    idx2 <- sort(c(which(naldx), idx))
+    res2 <- res[idx2, c(idname(p), hzidname(p), depthcol, hzdesgn, "pattern")]
     
   } else {
     res2 <- suppressWarnings(FUN(res, na.rm = na.rm))
@@ -215,7 +222,7 @@ maxDepthOf <- function(p,
                        no.contact.depth = NULL,
                        no.contact.assigned = NA,
                        na.rm = TRUE) {
-    .funDepthOf(
+   .funDepthOf(
       p = p,
       pattern = pattern,
       FUN = max,
